DeleteOne

Struct DeleteOne 

pub struct DeleteOne<E: EntityTrait>(/* private fields */);
A request to delete an ActiveModel.

The primary key must be set. Otherwise, it’s impossible to generate the SQL condition and find the record. In that case, exec will return an error and not send any queries to the database.

If you want to use QueryTrait and access the generated SQL query, you need to convert into ValidatedDeleteOne first.

Implementations



impl<E> DeleteOne<E>
where E: EntityTrait,

pub async fn exec<C>(self, db: &C) -> Result<DeleteResult, DbErr>
where C: ConnectionTrait,

Execute a DELETE operation on one ActiveModel

pub async fn exec_with_returning<C>( self, db: &C, ) -> Result<Option<E::Model>, DbErr>
where C: ConnectionTrait,

Execute an delete operation and return the deleted model



impl<E: EntityTrait> DeleteOne<E>

pub fn validate(self) -> Result<ValidatedDeleteOne<E>, DbErr>

Check whether the primary key is set and we can proceed with the operation.