Struct SelectFour
pub struct SelectFour<E, F, G, H, TOP>{ /* private fields */ }Expand description
Perform a SELECT operation on 4 Models
Implementations
impl<E, F, G, H, TOP> SelectFour<E, F, G, H, TOP>
impl<E, F, G, H, TOP> SelectFour<E, F, G, H, TOP>
pub fn find_also<T, I>(
self,
_: T,
_: I,
) -> SelectFive<E, F, G, H, I, TopologyStar>
pub fn find_also<T, I>( self, _: T, _: I, ) -> SelectFive<E, F, G, H, I, TopologyStar>
Left Join with a Related Entity and select all Entities.
impl<E, F, G, H, TOP> SelectFour<E, F, G, H, TOP>
impl<E, F, G, H, TOP> SelectFour<E, F, G, H, TOP>
pub fn into_model<M, N, O, P>(self) -> Selector<SelectFourModel<M, N, O, P>>
pub fn into_model<M, N, O, P>(self) -> Selector<SelectFourModel<M, N, O, P>>
Perform a conversion into a SelectFourModel
pub fn into_partial_model<M, N, O, P>(
self,
) -> Selector<SelectFourModel<M, N, O, P>>
pub fn into_partial_model<M, N, O, P>( self, ) -> Selector<SelectFourModel<M, N, O, P>>
Perform a conversion into a SelectFourModel with PartialModel
pub fn into_json(
self,
) -> Selector<SelectFourModel<JsonValue, JsonValue, JsonValue, JsonValue>>
pub fn into_json( self, ) -> Selector<SelectFourModel<JsonValue, JsonValue, JsonValue, JsonValue>>
Convert the Models into JsonValue
pub async fn one<C>(
self,
db: &C,
) -> Result<Option<(E::Model, Option<F::Model>, Option<G::Model>, Option<H::Model>)>, DbErr>where
C: ConnectionTrait,
pub async fn one<C>(
self,
db: &C,
) -> Result<Option<(E::Model, Option<F::Model>, Option<G::Model>, Option<H::Model>)>, DbErr>where
C: ConnectionTrait,
Get one Model from the Select query
pub async fn all<C>(
self,
db: &C,
) -> Result<Vec<(E::Model, Option<F::Model>, Option<G::Model>, Option<H::Model>)>, DbErr>where
C: ConnectionTrait,
pub async fn all<C>(
self,
db: &C,
) -> Result<Vec<(E::Model, Option<F::Model>, Option<G::Model>, Option<H::Model>)>, DbErr>where
C: ConnectionTrait,
Get all Models from the Select query
pub async fn stream<'a: 'b, 'b, C>(
self,
db: &'a C,
) -> Result<impl Stream<Item = Result<(E::Model, Option<F::Model>, Option<G::Model>, Option<H::Model>), DbErr>> + 'b, DbErr>
pub async fn stream<'a: 'b, 'b, C>( self, db: &'a C, ) -> Result<impl Stream<Item = Result<(E::Model, Option<F::Model>, Option<G::Model>, Option<H::Model>), DbErr>> + 'b, DbErr>
Stream the results of a Select operation on a Model
pub async fn stream_partial_model<'a: 'b, 'b, C, M, N, O, P>(
self,
db: &'a C,
) -> Result<impl Stream<Item = Result<(M, Option<N>, Option<O>, Option<P>), DbErr>> + 'b + Send, DbErr>where
C: ConnectionTrait + StreamTrait + Send,
M: PartialModelTrait + Send + 'b,
N: PartialModelTrait + Send + 'b,
O: PartialModelTrait + Send + 'b,
P: PartialModelTrait + Send + 'b,
pub async fn stream_partial_model<'a: 'b, 'b, C, M, N, O, P>(
self,
db: &'a C,
) -> Result<impl Stream<Item = Result<(M, Option<N>, Option<O>, Option<P>), DbErr>> + 'b + Send, DbErr>where
C: ConnectionTrait + StreamTrait + Send,
M: PartialModelTrait + Send + 'b,
N: PartialModelTrait + Send + 'b,
O: PartialModelTrait + Send + 'b,
P: PartialModelTrait + Send + 'b,
Stream the result of the operation with PartialModel