Struct UpdateOne
pub struct UpdateOne<A: ActiveModelTrait>(/* private fields */);Expand description
A request to update an ActiveModel.
The primary key must be set.
Otherwise, it’s impossible to generate the SQL condition and find the record.
In that case, exec will return an error and not send any queries to the database.
If you want to use QueryTrait and access the generated SQL query,
you need to convert into ValidatedUpdateOne first.
Implementations
impl<A> UpdateOne<A>where
A: ActiveModelTrait,
impl<A> UpdateOne<A>where
A: ActiveModelTrait,
impl<A: ActiveModelTrait> UpdateOne<A>
impl<A: ActiveModelTrait> UpdateOne<A>
pub fn validate(self) -> Result<ValidatedUpdateOne<A>, DbErr>
pub fn validate(self) -> Result<ValidatedUpdateOne<A>, DbErr>
Check whether the primary key is set and we can proceed with the operation.